==> lms-1.4.5+libs.tar.gz: lms/modules/netdevadd.php <==
<?php

/*
 * LMS version 1.4.5 Persus
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: netdevadd.php,v 1.9.2.2 2005/01/01 19:19:56 alec Exp $
 */

$netdevdata = $_POST['netdev'];

if(isset($netdevdata)) {
	// Jakby to dziaao to by byo mio... :P
	//if($netdevdata['ports'] !="" && !eregi("^[0-9]{,4}$",$netdevdata['ports']))
        //        $error['ports'] = "Podana ilo portw jest bdna!";
	if($netdevdata['ports'] =='')
		$netdevdata['ports'] = 0;
	if($netdevdata['name'] == '')
		$error['name'] = 'Pole nazwa nie moe by puste!';
	elseif(strlen($netdevdata['name'])>32)
		$error['name'] = 'Podana nazwa jest za duga!';

        if(!$error)
        {
	    $netdevid=$LMS->NetDevAdd($netdevdata);
	    header('Location: ?m=netdevinfo&id='.$netdevid);
	    die;
        }
}
		

$layout['pagetitle'] = 'Nowe urzdzenie';

$SMARTY->assign('error',$error);
$SMARTY->assign('netdev',$netdevdata);
$SMARTY->display('netdevadd.html');

?>

==> lms-1.6.1+libs.tar.gz: lms/modules/netdevadd.php <==
<?php

/*
 * LMS version 1.6.1 Ishta
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: netdevadd.php,v 1.14.2.1 2005/05/13 20:10:04 alec Exp $
 */

if(isset($_POST['netdev']))
{
	$netdevdata = $_POST['netdev'];

	if($netdevdata['ports'] == '')
		$netdevdata['ports'] = 0;
	if($netdevdata['name'] == '')
		$error['name'] = trans('Device name is required!');
	elseif(strlen($netdevdata['name'])>32)
		$error['name'] = trans('Device name is too long (max.32 characters)!');

        if(!$error)
        {
	    $netdevid = $LMS->NetDevAdd($netdevdata);
	    $SESSION->redirect('?m=netdevinfo&id='.$netdevid);
        }
	
	$SMARTY->assign('error', $error);
	$SMARTY->assign('netdev', $netdevdata);
}
		
$layout['pagetitle'] = trans('New Device');

$SMARTY->display('netdevadd.html');

?>
